@@ -10,7 +10,11 @@ fn main() {
         JoinTheDots::Interactive(_) => subcommands::interactive_subcommand_handler(),
     };
     if let Err(error) = result {
-        println!("{} {}", style("Error:").red().dim(), error.to_string().replace("\n", "\n       "));
+        println!(
+            "{} {}",
+            style("Error:").red().dim(),
+            error.to_string().replace("\n", "\n       ")
+        );
         exit(1);
     }
 }
