@@ -10,7 +10,7 @@ use std::{
 };
 
 use crate::{
-    git::operations::{add_and_commit, get_head_hash, push},
+    git::operations::{add_and_commit, get_repo_dir, push},
     utils::get_theme,
 };
 
@@ -43,25 +43,27 @@ impl Manifest {
 
     pub fn install(
         &self,
-        repo: Repository,
+        repo: &Repository,
         install_all: bool,
         target_dotfiles: Vec<String>,
         force_install: bool,
+        trust: bool,
     ) -> Result<(), Box<dyn Error>> {
         let theme = get_theme();
-        let head_hash = get_head_hash(&repo)?;
 
         let mut skip_install_commands = false;
 
         let dotfiles = self.get_target_dotfiles(target_dotfiles, install_all);
         let mut aggregated_metadata = AggregatedDotfileMetadata::get_or_create()?;
 
-        if self.has_unexecuted_run_stages(
-            Some(dotfiles.iter().map(|(v, _)| v.as_str()).collect()),
-            &aggregated_metadata,
-        ) {
+        if !trust
+            && self.has_unexecuted_run_stages(
+                Some(dotfiles.iter().map(|(v, _)| v.as_str()).collect()),
+                &aggregated_metadata,
+            )
+        {
             warn!(
-                "! Some of the dotfiles being installed contain pre_install and/or post_install \
+                "Some of the dotfiles being installed contain pre_install and/or post_install \
                 steps. If you do not trust this manifest, you can skip running them."
             );
             skip_install_commands = Confirm::with_theme(&theme)
@@ -72,9 +74,7 @@ impl Manifest {
                 .unwrap();
         }
 
-        // Safe to unwrap here, repo.path() points to .git folder. Path will always
-        // have a component after parent.
-        let repo_dir = repo.path().parent().unwrap().to_owned();
+        let repo_dir = get_repo_dir(&repo);
 
         for (dotfile_name, dotfile) in dotfiles {
             let mut origin_path_buf = PathBuf::from(&repo_dir);
@@ -102,7 +102,7 @@ impl Manifest {
                 .map(|d| (*d).clone());
 
             let metadata =
-                dotfile.install(&repo_dir, maybe_metadata, &head_hash, skip_install_commands)?;
+                dotfile.install(&repo, maybe_metadata, skip_install_commands, force_install)?;
 
             aggregated_metadata
                 .data
@@ -173,17 +173,18 @@ impl Manifest {
         target_dotfiles: Vec<String>,
         commit_msg: Option<&str>,
         aggregated_metadata: Option<AggregatedDotfileMetadata>,
+        use_naive_sync: bool,
     ) -> Result<(), Box<dyn Error>> {
         let theme = get_theme();
 
         let dotfiles = self.get_target_dotfiles(target_dotfiles, sync_all);
         let mut commit_hashes = vec![];
 
-        if aggregated_metadata.is_none() {
+        if aggregated_metadata.is_none() && !use_naive_sync {
             println!(
                 "{}",
                 style(
-                    "! Could not find any metadata on the currently installed dotfiles. Proceed with naive sync and overwrite remote files?"
+                    "Could not find any metadata on the currently installed dotfiles. Proceed with naive sync and overwrite remote files?"
                 )
                 .yellow()
             );
@@ -280,7 +281,7 @@ impl IntoIterator for Manifest {
 #[cfg(test)]
 mod tests {
     use std::{
-        fs::File,
+        fs::{read_to_string, File},
         io::Write,
         path::{Path, PathBuf},
     };
@@ -290,8 +291,8 @@ mod tests {
 
     const SAMPLE_MANIFEST: &str = r"
 kitty:
-  file: kitty.conf
-  target: ~/.config/kitty/kitty.conf
+  file: dotfile
+  target: ~/some/path/here
         ";
 
     #[test]
@@ -305,12 +306,90 @@ kitty:
         let manifest = Manifest::get(&path).unwrap();
 
         let kitty_dotfile = Dotfile {
-            file: "kitty.conf".to_string(),
-            target: PathBuf::from("~/.config/kitty/kitty.conf"),
+            file: "dotfile".to_string(),
+            target: PathBuf::from("~/some/path/here"),
             pre_install: None,
             post_install: None,
         };
 
         assert_eq!(manifest.data["kitty"], kitty_dotfile);
     }
+
+    #[test]
+    fn test_manifest_install() {
+        let repo_dir = tempdir().expect("Could not create temporary repo dir");
+        let repo = Repository::init(&repo_dir).expect("Could not initialise repository");
+
+        let dotfile_dir = tempdir().expect("Could not create temporary dotfile dir");
+        let target_path = dotfile_dir.path().join("dotfile");
+
+        // Create file in repo
+        let filepath = repo_dir.path().to_owned().join("dotfile");
+        File::create(filepath.to_owned()).expect("Could not create file in repo");
+        let _commit = add_and_commit(
+            &repo,
+            Some(vec![&filepath]),
+            "commit message",
+            Some(vec![]),
+            Some("HEAD"),
+        )
+        .expect("Failed to commit to repository");
+
+        let manifest: Manifest = serde_yaml::from_str(
+            &SAMPLE_MANIFEST.replace("~/some/path/here", &target_path.to_string_lossy()),
+        )
+        .unwrap();
+
+        manifest
+            .install(&repo, true, vec![], true, false)
+            .expect("Failed to install manifest");
+        assert!(Path::exists(&target_path));
+    }
+
+    #[test]
+    fn test_manifest_sync() {
+        let repo_dir = tempdir().expect("Could not create temporary repo dir");
+        let repo = Repository::init(&repo_dir).expect("Could not initialise repository");
+
+        let dotfile_dir = tempdir().expect("Could not create temporary dotfile dir");
+        let target_path = dotfile_dir.path().join("dotfile");
+
+        // Create file in repo
+        let repo_dotfile_path = repo_dir.path().join("dotfile");
+        File::create(repo_dotfile_path.to_owned()).expect("Could not create file in repo");
+        let _commit = add_and_commit(
+            &repo,
+            Some(vec![&repo_dotfile_path]),
+            "commit message",
+            Some(vec![]),
+            Some("HEAD"),
+        )
+        .expect("Failed to commit to repository");
+
+        // Create dotfile "on the local system"
+        let mut file =
+            File::create(target_path.to_owned()).expect("Could not create file in tempdir");
+        file.write_all(b"These are local changes on the system")
+            .expect("Failed to write to dotfile");
+
+        let manifest: Manifest = serde_yaml::from_str(
+            &SAMPLE_MANIFEST.replace("~/some/path/here", &target_path.to_string_lossy()),
+        )
+        .unwrap();
+
+        let err = manifest
+            .sync(&repo, true, vec![], None, None, true)
+            .unwrap_err();
+
+        // FIXME: This is a very dodgy test, maybe setup a mock repo for pushing to?
+        assert_eq!(
+            err.to_string(),
+            "remote 'origin' does not exist; class=Config (7); code=NotFound (-3)"
+        );
+
+        assert_eq!(
+            read_to_string(&repo_dotfile_path).unwrap(),
+            "These are local changes on the system"
+        );
+    }
 }
