@@ -11,7 +11,6 @@ use crate::{
 pub fn sync_subcommand_handler(args: SyncSubcommandArgs) -> Result<(), Box<dyn Error>> {
     let url = get_host_git_url(&args.repository, &args.source, &args.method)?;
     let target_dir = tempdir()?;
-    println!("{:?}", target_dir);
 
     let repo = clone_repo(&url, target_dir.path())?;
 
@@ -26,5 +25,6 @@ pub fn sync_subcommand_handler(args: SyncSubcommandArgs) -> Result<(), Box<dyn E
         args.target_dotfiles,
         args.commit_msg.as_deref(),
         AggregatedDotfileMetadata::get()?,
+        args.naive,
     )
 }
